# Metric Forge

<img src="static/MetricForge.png" alt="Description of the image" width="300" height="300">

Metric Forge is your ultimate toolkit for measuring and evaluating performance across various business domains.